@@ -1,7 +1,7 @@
 """ Serializers for the staff_grader app """
 
 from openassessment.staffgrader.serializers.submission_list import (
-    MissingContextException, SubmissionListScoreSerializer, SubmissionListSerializer
+    MissingContextException, SubmissionListScoreSerializer, SubmissionListSerializer, TeamSubmissionListSerializer
 )
 from openassessment.staffgrader.serializers.submission_lock import SubmissionLockSerializer
 from openassessment.staffgrader.serializers.assessments import (
